@@ -17,10 +17,6 @@ from dsocli.utils import set_dict_value
 
 
 default_spec = {
-    'allowGroups': 'no',
-    'prependGroups': 'yes',
-    'groupDelimiter': '/',
-    'nestedDelimiter': '.',
 }
 
 
@@ -36,7 +32,6 @@ class AwsSsmParameterProvider(ParameterProvider):
     def __init__(self):
         super().__init__('parameter/aws/ssm/v1')
 
-###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
 
     def get_parameter_prefix(self, project, application, stage, key=None):
@@ -59,15 +54,8 @@ class AwsSsmParameterProvider(ParameterProvider):
 
     def get_key_validator(self):
 
-        allowGroups = Config.parameter_spec('allowGroups')
-        if allowGroups is None:
-            Logger.debug(f"'allowGroups' is not set for the parameter provider, defaulted to '{default_spec['allowGroups']}'.")
-            allowGroups = default_spec['allowGroups']
-
-        if allowGroups:
-            return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
-        else:
-            return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
+        # return r"^([a-zA-Z][a-zA-Z0-9]*/)?([a-zA-Z][a-zA-Z0-9_.-]*)$"
+        return r"^([a-zA-Z][a-zA-Z0-9_.-]*)$"
 
 ###--------------------------------------------------------------------------------------------
 
@@ -101,7 +89,6 @@ class AwsSsmParameterProvider(ParameterProvider):
 ###--------------------------------------------------------------------------------------------
 
     def locate_parameter(self, project, application, stage, key, uninherited=False):
-
         Logger.debug(f"Locating SSM parameter: project={project}, application={application}, stage={stage}, key={key}")
         paths = self.get_ssm_search_paths(project, application, stage, key, uninherited)
         Logger.debug(f"SSM paths to search in order: {paths}")
@@ -122,7 +109,7 @@ class AwsSsmParameterProvider(ParameterProvider):
             value = parameter['Value']
             if key in parameters:
                 Logger.warn("Inherited parameter '{0}' overridden.".format(key))
-            parameters[key] = value
+            parameters[key] = {'Value': value, 'Path': path}
         return parameters
 
 ###--------------------------------------------------------------------------------------------
@@ -166,34 +153,14 @@ class AwsSsmParameterProvider(ParameterProvider):
     def list(self, project, application, stage, uninherited):
         ### construct search path in hierachy with no key specified in reverse order
         paths = list(reversed(self.get_ssm_search_paths(project, application, stage, None, uninherited)))
-        Logger.debug(f"SSM paths to search in order: {paths}")
+        # Logger.debug(f"SSM paths to search in order: {paths}")
         parameters = {}
         for path in paths:
             self.load_ssm_path(parameters, path)
 
-        prependGroups = Config.parameter_spec('prependGroups')
-        if prependGroups is None:
-            Logger.debug(f"'prependGroups' is not set for the parameter provider, defaulted to '{default_spec['prependGroups']}'.")
-            prependGroups = default_spec['prependGroups']
-
-        groupDelimiter = Config.parameter_spec('groupDelimiter')
-        if groupDelimiter is None:
-            Logger.debug(f"'groupDelimiter' is not set for the parameter provider, defaulted to '{default_spec['groupDelimiter']}'.")
-            groupDelimiter = default_spec['groupDelimiter']
-
-        nestedDelimiter = Config.parameter_spec('nestedDelimiter')
-        if nestedDelimiter is None:
-            Logger.debug(f"'nestedDelimiter' is not set for the parameter provider, defaulted to '{default_spec['nestedDelimiter']}'.")
-            nestedDelimiter = default_spec['nestedDelimiter']
-
-        Logger.info("Merging parameters...")
-        result = {}
-        for key, value in parameters.items():
-            if prependGroups:
-                key = key.replace('.', nestedDelimiter).replace('/', groupDelimiter)
-            else:
-                key = key.split('/')[-1].replace('.', nestedDelimiter)
-            set_dict_value(result, key.split('.'), value, overwrite_parent=True,  overwrite_children=True)
+        result = {'Parameters': []}
+        for item in parameters.items():
+            result['Parameters'].append({'Key': item[0], 'Value': item[1]['Value'], 'Path': item[1]['Path']})
 
         return result
 
@@ -207,18 +174,19 @@ class AwsSsmParameterProvider(ParameterProvider):
         path = self.get_parameter_prefix(project, application, stage=stage, key=key)
         Logger.info(f"Adding SSM parameter: path={path}")
         ssm.put_parameter(Name=path, Value=value, Type='String', Overwrite=True)
+        return path
 
 ###--------------------------------------------------------------------------------------------
 
     def get(self, project, application, stage, key):
-        found = self.locate_parameter(stage, key)
+        found = self.locate_parameter(project, application, stage, key)
         if not found or len(found) == 0:
-            raise DSOException(f"Parameter '{key}' not found nor inherited: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+            raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             # if len(found) > 1:
             #     Logger.warn(f"More than one parameter found at '{found[0]['Name']}'. The first one taken, and the rest were discarded.")
             if not found[0]['Type'] in ['String', 'StringList']:
-                raise DSOException(f"Parameter not found: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Getting SSM parameter: path={found[0]['Name']}")
         result = ssm.get_parameter(Name=found[0]['Name'], WithDecryption=True)
         return result['Parameter']['Value']
@@ -229,14 +197,15 @@ class AwsSsmParameterProvider(ParameterProvider):
         ### only parameters owned by the stage can be deleted, hence uninherited=True
         found = self.locate_parameter(project, application, stage, key, uninherited=True)
         if not found or len(found) == 0:
-            raise DSOException(f"Parameter not found: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+            raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         else:
             # if len(found) > 1:
             #     Logger.warn(f"More than one parameter found at '{found[0]['Name']}'. The first one taken, and the rest were discarded.")
             if not found[0]['Type'] in ['String', 'StringList']:
-                raise DSOException(f"Parameter not found: project={project}, application={application}, stage={Stages.shorten(stage)}, key={key}")
+                raise DSOException(f"Parameter '{key}' not found: project={project}, application={application}, stage={Stages.shorten(stage)}")
         Logger.info(f"Deleting SSM parameter: path={found[0]['Name']}")
         ssm.delete_parameter(Name=found[0]['Name'])
+        return found[0]['Name']
 
 
 ###--------------------------------------------------------------------------------------------
